History
========

0.2.0 (2010-07-05)
-------------------
* fallbacks for json import
* improved HTTP error handling
* unit tests

0.2.0 (2010-06-27)
-------------------
* add cli client to send notifications

0.1.1 (2010-06-25)
-------------------
* fix typo which prevented proper function call of subscribe_user

0.1.0 (2010-06-17)
-------------------
* add basic API access
